@@ -25,12 +25,12 @@ class Q_MULTIMEDIA_EXPORT QImageVideoBuffer : public QAbstractVideoBuffer
 public:
     QImageVideoBuffer(QImage image);
 
-    QVideoFrame::MapMode mapMode() const override;
-
     MapData map(QVideoFrame::MapMode mode) override;
 
     void unmap() override;
 
+    QImage underlyingImage() const;
+
 private:
     QVideoFrame::MapMode m_mapMode = QVideoFrame::NotMapped;
     QImage m_image;
